SystemOrganization addCategory: #'Seaside-Environment'!

WAObject subclass: #WAAdmin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/17/2008 20:58'!
clearConfigurationCaches
	WASystemConfiguration clearAllDescriptions! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/14/2008 10:23'!
clearSessions
	WARegistry clearAllHandlers! !

!WAAdmin class methodsFor: 'class initialization' stamp: 'jf 9/15/2008 00:30'!
initialize
	self registerDefaultRequestHandlers.! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 9/17/2008 20:13'!
register: aComponent at: aString
	"Use this to programatically register a component as an application."
	"WARenderLoopConfiguration is added by default because most users will use WASession and the Render Loop."
	| application |
	application := WAApplication register: aString.
	application configuration
		removeParent: WASessionConfiguration instance; "make the chain slightly cleaner"
		addParent: WARenderLoopConfiguration instance.
	application
		preferenceAt: #rootClass put: aComponent;
		preferenceAt: #exceptionHandler put: WAHtmlErrorHandler;
		preferenceAt: #responseFactory put: WAHtmlResponseFactory.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'MAD 9/13/2008 17:10'!
register: aComponent at: aString user: user password: password
	"Like #registerApplicationAt: root: but additionally adds password protection."
	| application |
	application := self register: aComponent at: aString.
	application configuration addParent: WAAuthConfiguration instance.
	application 
		preferenceAt: #login
		put: user.
	application 
		preferenceAt: #passwordHash
		put: (SeasidePlatformSupport secureHashFor: password).
	application
		addFilter: WAAuthenticationFilter new.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 9/15/2008 00:23'!
registerDefaultRequestHandlers
	WADispatcher resetDefault.
	WADispatcher default register: (WAFileHandler named: 'files').! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/15/2008 00:33'!
reloadApplications
	WADispatcher resetDefault.
	WASystemConfiguration clearAllDescriptions.
	self registerDefaultRequestHandlers.
	WAComponent allSubclasses do: [ :each |
		(each class includesSelector: #initialize)
			ifTrue: [ each initialize ] ]! !

WAErrorHandler subclass: #WAHtmlErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlErrorHandler commentStamp: 'jf 9/17/2008 20:52' prior: 0!
This error handler returns a simple HTML error message response.

It provides two methods to allow the easy creation of custom error responses:

#titleForException:  - can be used to override the text displayed in the title
#renderContentForException:  - can be used to fully customize the HTML output!

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 9/14/2008 20:30'!
handleDefault: anException
	| response content |
	response := WAResponse new.
	response internalError.
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: (self titleForException: anException) ];
		render: [ :html | self renderContentForException: anException on: html ].
	response nextPutAll: content.
	^ response! !

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 9/14/2008 20:32'!
renderContentForException: anException on: html
	html heading level1; with: anException description.
	html paragraph: 'Your request could not be completed. An error occurred.'! !

!WAHtmlErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 20:28'!
titleForException: anException
	^ anException description! !

!WAComponent class methodsFor: '*Seaside-Environment' stamp: 'jf 9/24/2008 10:41'!
registerAsApplication: aString 
	self seasideDeprecatedApi: 'WAComponent class>>registerAsApplication:'
		details: 'Use WAAdmin>>register:at:'.
	^ WAAdmin 	register: self at: aString! !

!WADispatcher class methodsFor: '*seaside-environment' stamp: 'jf 9/24/2008 10:38'!
resetAll
	self seasideDeprecatedApi: 'WADispatcher class>>resetAll'
		details: 'Use WAAdmin>>reloadApplications.'.
	WAAdmin reloadApplications! !

WAResponseFactory subclass: #WAHtmlResponseFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlResponseFactory class methodsFor: 'as yet unclassified' stamp: 'jf 9/14/2008 00:36'!
forbiddenForContext: aRequestContext
	| response content |
	response := WAResponse new.
	response forbidden.
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Forbidden' ];
		render: [ :html |
			html heading level1; with: [
				html text: 'Error: you are forbidden to access "'.
				html text: aRequestContext request url.
				html text: '"' ] ].
	response nextPutAll: content.
	^ response! !

!WAHtmlResponseFactory class methodsFor: 'as yet unclassified' stamp: 'jf 9/14/2008 00:35'!
notFoundForContext: aRequestContext 
	| response content |
	response := WAResponse new.
	response notFound.
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Not Found' ];
		render: [ :html |
			html heading level1; with: [
				html text: 'Error: "'.
				html text: aRequestContext request url.
				html text: '" not found' ] ].
	response nextPutAll: content.
	^ response! !

!WAHtmlResponseFactory class methodsFor: 'as yet unclassified' stamp: 'pmm 9/14/2008 13:56'!
pageExpiredForContext: aRequestContext
	| content |
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Page Expired' ];
		render: [ :html | 
			html heading: 'Page Expired'.
			html paragraph: 'This page has expired. Please use the back-button to navigate to the last valid page.' ].
	^WAResponse new
		nextPutAll: content;
		doNotCache;
		yourself! !

!WAHtmlResponseFactory class methodsFor: 'as yet unclassified' stamp: 'jf 9/14/2008 00:36'!
refreshAfter: aNumber location: aUrlOrString message: aString
	| response document |
	response := WAResponse new.
	response refreshAfter: aNumber location: aUrlOrString.
	
	document := WARenderCanvas builder
		fullDocument: true;
		render: [ :html |
			html heading level1; with: aString.
			html paragraph: [
				html text: 'You are being redirected to '.
				html anchor
					url: aUrlOrString;
					with: aUrlOrString seasideString ] ].
	
	response nextPutAll: document.
		
	^ response! !
WAAdmin initialize!
